[PATCH 40/45] writeback: requeue_io_wait() on I_SYNC locked inode

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Use requeue_io_wait() if inode is being synced by others.
This queue won't be busy retried, so avoids busy loops.

Cc: Jan Kara <jack@xxxxxxx> 
Cc: Michael Rubin <mrubin@xxxxxxxxxx>
Cc: Peter Zijlstra <peterz@xxxxxxxxxxxxx>
Signed-off-by: Fengguang Wu <wfg@xxxxxxxxxxxxxxxx>
---
 fs/fs-writeback.c |    6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

--- linux.orig/fs/fs-writeback.c	2009-10-07 14:32:51.000000000 +0800
+++ linux/fs/fs-writeback.c	2009-10-07 14:32:52.000000000 +0800
@@ -526,14 +526,14 @@ writeback_single_inode(struct inode *ino
 	if (inode->i_state & I_SYNC) {
 		/*
 		 * If this inode is locked for writeback and we are not doing
 		 * writeback-for-data-integrity, move it to b_more_io so that
 		 * writeback can proceed with the other inodes on s_io.
 		 *
 		 * We'll have another go at writing back this inode when we
 		 * completed a full scan of b_io.
 		 */
 		if (!wait) {
-			requeue_io(inode);
+			requeue_io_wait(inode);
 			return 0;
 		}
 
@@ -526,14 +526,14 @@ writeback_single_inode(struct inode *ino
 		/*
 		 * If this inode is locked for writeback and we are not doing
-		 * writeback-for-data-integrity, move it to b_more_io so that
-		 * writeback can proceed with the other inodes on s_io.
+		 * writeback-for-data-integrity, move it to b_more_io_wait so
+		 * that writeback can proceed with the other inodes on b_io.
 		 *
 		 * We'll have another go at writing back this inode when we


--
To unsubscribe from this list: send the line "unsubscribe linux-fsdevel" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html

[Index of Archives]     [Linux Ext4 Filesystem]     [Union Filesystem]     [Filesystem Testing]     [Ceph Users]     [Ecryptfs]     [AutoFS]     [Kernel Newbies]     [Share Photos]     [Security]     [Netfilter]     [Bugtraq]     [Yosemite News]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux Cachefs]     [Reiser Filesystem]     [Linux RAID]     [Samba]     [Device Mapper]     [CEPH Development]
  Powered by Linux